==> 1.0.1.tar.gz: lib/creation.dart <==
import 'variables.dart';
import 'package:geiger_localstorage/geiger_localstorage.dart';
import 'data.dart';
import 'dart:developer';

Future createThreats() async {

    //print(await Storage.controller!.get(':Global:threats'));


  Node threats = NodeImpl(':Global:threats','test');
    try {
      await Storage.controller!.addOrUpdate(threats);

    } catch (e) {
      print(e);
    }

    for ( var object in data.threats){

      try {

        Node temp = NodeImpl(object['UUID']!,'test',':Global:threats');
        await temp.addOrUpdateValue(NodeValueImpl('name', object['Name']!));
        await temp.addOrUpdateValue(NodeValueImpl('GEIGER_threat', object['GEIGER-threat']!));
        await threats.addChild(temp);
      }
      // ignore: empty_catchess
      catch(e){
          print(e);
      }
    }


  try {
    await Storage.controller!.addOrUpdate(threats);
  } catch (e, s) {
    print(e);
  }

  //print(await Storage.controller!.get(':Global:threats'));

}

Future createPlugin() async{

  //:Local:plugin
  Node plugins = NodeImpl(':Local:plugin','');
  try {
    await Storage.controller!.addOrUpdate(plugins);
  } catch (e, s) {
    print(e);
  }

 // final input =  File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/local.csv').openRead();
 // final fields = await input.transform(utf8.decoder).transform(CsvToListConverter()).toList();

 for ( var object in data.local){

  try {

      Node temp = NodeImpl(object['UUID']!,'',':Local:plugin');
      await temp.addOrUpdateValue(NodeValueImpl('name', object['Name']!));
      await temp.addOrUpdateValue(NodeValueImpl('company', object['company']!));

      await Storage.controller!.addOrUpdate(temp);
    }
    catch(e){
     log(e.toString());
    }
  }

  //print(await Storage.controller!.get(':Local:plugin'));
}


Future createProfiles() async{

  //":Global:profiles"
  Node profiles = NodeImpl(':Global:profiles','');
  try {
    await Storage.controller!.addOrUpdate(profiles);
  } catch (e, s) {
    print(e);
  }

  //  Map x = json.decode(await File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/profiles.json').readAsString());


  var t =  data.profiles.entries.iterator;


  while(t.moveNext()){

     var profile = t.current.value;

     Node temp = NodeImpl(profile['UUID'].toString(),'',':Global:profiles');
     await temp.addOrUpdateValue(NodeValueImpl('name', t.current.key));

     var pp =  profile.entries.iterator;

     //print('=========');
     while(pp.moveNext()){

        if(pp.current.key != 'UUID'){

          NodeValue nodeValue = NodeValueImpl(pp.current.key.toString(), pp.current.value.toString());
          await temp.addOrUpdateValue(nodeValue);
          //print(pp.current.key + pp.current.value);
          //log(temp.toString());
        }

     }

     try {
      //await profiles.addChild(temp);

      await Storage.controller!.addOrUpdate(temp);
     } catch (e, s) {
      print(e);
     }

  }


  var prget = await Storage.controller!.get(':Global:profiles');
  var datas = await prget.getChildren();
  log(datas.toString());
  //print(datas.toString());

}

Future createRecommendations() async{


  Node recommendations = NodeImpl(':Global:Recommendations','');
  try {
    await Storage.controller!.addOrUpdate(recommendations);
  } catch (e, s) {
    print(s);
  }

  //Map x = json.decode(await File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/recommendations.json').readAsString());


  var t =  data.reco.entries.iterator;

  while(t.moveNext()){

    var recommendation = t.current.value;
    Node temp = NodeImpl(recommendation['UUID'].toString(), '',':Global:Recommendations');
    await temp.addOrUpdateValue(NodeValueImpl('short', recommendation['short'].toString()));
    await temp.addOrUpdateValue(NodeValueImpl('relatedThreatsWeights', recommendation['relatedThreatsWeights'].toString()));
    await temp.addOrUpdateValue(NodeValueImpl('RecommendationType', recommendation['RecommendationType'].toString()));
    await Storage.controller!.addOrUpdate(temp);
    await recommendations.addChild(temp);
  }



  try {
    await Storage.controller!.addOrUpdate(recommendations);
  } catch (e, s) {
    print(s);
  }

//  var get = await Storage.controller!.get(':Global:Recommendations');
//  print(await get.getChildren());
}

Future createEnterprise() async{

  //:Enterprise
//  Node enterprise = NodeImpl(':Enterprise');
//  Storage.controller!.addOrUpdate(enterprise);

//  final input =  File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/Enterprise.csv').openRead();
//  final fields = await input.transform(utf8.decoder).transform(CsvToListConverter()).toList();

//  for ( var str in fields[0].toString().replaceAll('[', '').split('\n') ){

    try {

      Node temp = NodeImpl(data.enter['UUID'].toString(),'', ':Enterprise');
      await temp.addOrUpdateValue(NodeValueImpl('name', data.enter['Name'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('location', data.enter['location'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('sector', data.enter['sector'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('associatedProfiles', data.enter['associatedProfiles'].toString()));

      await Storage.controller!.addOrUpdate(temp);
    }
    catch(e){

      print(e);

    }
 // }

//  var get = await Storage.controller!.get(':Enterprise');
//  print(await get.getChildren());

}


Future createEnterpriseDevices() async{

  //:Enterprise
//  Node enterprise = NodeImpl(':Enterprise');
//  Storage.controller!.addOrUpdate(enterprise);

//  final input =  File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/enterpriseDevices.csv').openRead();
//  final fields = await input.transform(utf8.decoder).transform(CsvToListConverter()).toList();


  for ( var str in data.enterDevice ){

    try {

      Node temp = NodeImpl(str['UUID'].toString(),'', ':Devices');
      await temp.addOrUpdateValue(NodeValueImpl('name', str['name'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('type', str['type'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('owner', str['owner'].toString()));
      await Storage.controller!.addOrUpdate(temp);
    }

    catch(e){

      print(e);
    }
  }

  Node temp = await Storage.controller!.get(':Devices:'+Storage.deviceUUID);
  await temp.addOrUpdateValue(NodeValueImpl('name', 'geiger'));
  await temp.addOrUpdateValue(NodeValueImpl('type', 'mobile'));
  await temp.addOrUpdateValue(NodeValueImpl('owner', Storage.userUUID));
  await Storage.controller!.addOrUpdate(temp);


//  var get = await Storage.controller!.get(':Devices');
//  print(await get.getChildren());

  //print(Storage.controller!.get(':Devices').getChildren());

}


Future createEnterpriseUsers() async {

  //":Global:profiles"
  Node enterpriseUsers = NodeImpl(':Enterprise:users','');
  try {
    await Storage.controller!.addOrUpdate(enterpriseUsers);
  } catch (e, s) {
    print(s);
  }

 // Map x = json.decode(await File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/enterpriseUsers.json').readAsString());


  var t =  data.enterUsers.entries.iterator;

  while(t.moveNext()){

    var nodeArrays = t.current.value;

    for(var node in nodeArrays){

      Node temp = NodeImpl(node['UUID'].toString(),'', ':Enterprise:users');
      await temp.addOrUpdateValue(NodeValueImpl('name',node['name'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('firstName',node['firstName'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('UUIDs',node['UUIDs'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('mainUser',node['mainUser'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('supervising',node['supervising'].toString()));

      await enterpriseUsers.addChild(temp);

    }


  }

  Node temp = NodeImpl(Storage.userUUID,'', ':Enterprise:users');
  await temp.addOrUpdateValue(NodeValueImpl('name','geiger'));
  await temp.addOrUpdateValue(NodeValueImpl('firstName','g'));
  await temp.addOrUpdateValue(NodeValueImpl('UUIDs',Storage.userUUID));
  await temp.addOrUpdateValue(NodeValueImpl('mainUser','1'));
  await temp.addOrUpdateValue(NodeValueImpl('supervising','328161f6-89bd-49f6-user-5a375ff56ben, 328161f6-89bd-49f6-user-5a375ff58cal, 328161f6-89bd-49f6-user-5a375ff58deb'));

  await enterpriseUsers.addChild(temp);

  try {
    await Storage.controller!.addOrUpdate(enterpriseUsers);
  } catch (e, s) {
    print(s);
  }
//
//  var get = await Storage.controller!.get(':Devices');
//  print(await get.getChildren());



}



//Future createLocal() async {
//
//  Storage.userUUID = await Storage().getUUID('currentUser');
//  print('proxy'+Storage.userUUID);
//
//  Storage.deviceUUID = await Storage().getUUID('currentDevice');
//
//  print('proxy'+Storage.deviceUUID);
//}



Future createDeviceData(var body) async{


  //create :Users:tool_iD:plugin_UUID:data node paths



  var t =  body.entries.iterator;

  var companyUUID = body.entries.first.value['cUUID'];

  await Storage.controller!.addOrUpdate(NodeImpl(companyUUID,'', ':Devices:' + Storage.deviceUUID));
  await Storage.controller!.addOrUpdate(NodeImpl('data','', ':Devices:' + Storage.deviceUUID + ':' + companyUUID));
  await Storage.controller!.addOrUpdate(NodeImpl('metrics','', ':Devices:' + Storage.deviceUUID + ':' + companyUUID+':data'));

  while(t.moveNext()){

  var node = t.current.value;


  Node temp = NodeImpl(node['mUUID'],'', ':Devices:' + Storage.deviceUUID + ':' + node['cUUID']+':data:metrics');
  await temp.addOrUpdateValue(NodeValueImpl('name', node['name']));
  await temp.addOrUpdateValue(NodeValueImpl('minValue', node['minValue']));
  await temp.addOrUpdateValue(NodeValueImpl('maxValue', node['maxValue']));
  await temp.addOrUpdateValue(NodeValueImpl('GEIGERvalue', node['GEIGERvalue']));
  await temp.addOrUpdateValue(NodeValueImpl('valueType', node['valueType']));
  await temp.addOrUpdateValue(NodeValueImpl('flag', node['flag']));
  await temp.addOrUpdateValue(NodeValueImpl('threatsImpact', node['threatsImpact']));

  await Storage.controller!.addOrUpdate(temp);


  }

  // print(await Storage.controller!.get(':Devices:' + Storage.deviceUUID + ':' + companyUUID +':data:metrics'));

}



Future createUserData(var body) async{


  //create :Users:tool_iD:plugin_UUID:data node paths

  body['name'] = 'Awareness and training scores';
  body['GEIGERvalue'] = '50';
  body['flag'] = '1';
//{geigerValue: 32.5, minValue: 0, cUUID: 5a6487c7-c1c5-4f28-995e-8805e45bf1a3, maxValue: 100, valueType: double, mUUID: 123e4567-e89b-42d3-a456-556642440sdk-m01, threatsImpact: 80efffaf-98a1-4e0a-8f5e-gr89388352ph,High;80efffaf-98a1-4e0a-8f5e-gr89388354sp,Hight;80efffaf-98a1-4e0a-8f5e-th89388365it,Hight;80efffaf-98a1-4e0a-8f5e-gr89388350ma,Medium;80efffaf-98a1-4e0a-8f5e-gr89388356db,Medium}

  //var t =  body.entries.iterator;

  var companyUUID = body['cUUID'];

  await Storage.controller!.addOrUpdate(NodeImpl(companyUUID,'', ':Users:' + Storage.userUUID));
  await Storage.controller!.addOrUpdate(NodeImpl('data','', ':Users:' + Storage.userUUID + ':' + companyUUID));
  await Storage.controller!.addOrUpdate(NodeImpl('metrics','', ':Users:' + Storage.userUUID + ':' + companyUUID+':data'));



  //while(t.moveNext()){

  //var node = t.current.value;


  Node temp = NodeImpl(body['mUUID'],'', ':Users:' + Storage.userUUID + ':' + body['cUUID']+':data:metrics');
  //print(temp.path);
  await temp.addOrUpdateValue(NodeValueImpl('name', body['name']));
  await temp.addOrUpdateValue(NodeValueImpl('minValue', body['minValue']));
  await temp.addOrUpdateValue(NodeValueImpl('maxValue', body['maxValue']));
  await temp.addOrUpdateValue(NodeValueImpl('GEIGERvalue', body['GEIGERvalue']));
  await temp.addOrUpdateValue(NodeValueImpl('valueType', body['valueType']));
  await temp.addOrUpdateValue(NodeValueImpl('flag', body['flag']));
  await temp.addOrUpdateValue(NodeValueImpl('threatsImpact', body['threatsImpact']));

  await Storage.controller!.addOrUpdate(temp);

  SearchCriteria s = SearchCriteria(searchPath: ':Users');
  s.set(Field.type,'GEIGERvalue');
  print(await s.evaluate(temp));


  //}

//  var prget = await Storage.controller!.get(':Users:' + Storage.userUUID + ':' + companyUUID +':data:metrics');
//  var re = await prget.getChildren();
//  log(re.toString());

}

==> 1.0.4.tar.gz: lib/creation.dart <==
import 'variables.dart';
import 'package:geiger_localstorage/geiger_localstorage.dart';
import 'data.dart';
import 'dart:developer';

Future createThreats() async {

    //print(await Storage.controller!.get(':Global:threats'));


  Node threats = NodeImpl(':Global:threats','test');
    try {
      await Storage.controller!.addOrUpdate(threats);

    } catch (e) {
      print(e);
    }

    for ( var object in data.threats){

      try {

        Node temp = NodeImpl(object['UUID']!,'test',':Global:threats');
        await temp.addOrUpdateValue(NodeValueImpl('name', object['Name']!));
        await temp.addOrUpdateValue(NodeValueImpl('GEIGER_threat', object['GEIGER-threat']!));
        await threats.addChild(temp);
      }
      // ignore: empty_catchess
      catch(e){
          print(e);
      }
    }


  try {
    await Storage.controller!.addOrUpdate(threats);
  } catch (e, s) {
    print(e);
  }

  //print(await Storage.controller!.get(':Global:threats'));

}

Future createPlugin() async{

  //:Local:plugin
  Node plugins = NodeImpl(':Local:plugin','');
  try {
    await Storage.controller!.addOrUpdate(plugins);
  } catch (e, s) {
    print(e);
  }

 // final input =  File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/local.csv').openRead();
 // final fields = await input.transform(utf8.decoder).transform(CsvToListConverter()).toList();

 for ( var object in data.local){

  try {

      Node temp = NodeImpl(object['UUID']!,'',':Local:plugin');
      await temp.addOrUpdateValue(NodeValueImpl('name', object['Name']!));
      await temp.addOrUpdateValue(NodeValueImpl('company', object['company']!));

      await Storage.controller!.addOrUpdate(temp);
    }
    catch(e){
     log(e.toString());
    }
  }

  //print(await Storage.controller!.get(':Local:plugin'));
}


Future createProfiles() async{

  //":Global:profiles"
  Node profiles = NodeImpl(':Global:profiles','');
  try {
    await Storage.controller!.addOrUpdate(profiles);
  } catch (e, s) {
    print(e);
  }

  //  Map x = json.decode(await File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/profiles.json').readAsString());


  var t =  data.profiles.entries.iterator;


  while(t.moveNext()){

     var profile = t.current.value;

     Node temp = NodeImpl(profile['UUID'].toString(),'',':Global:profiles');
     await temp.addOrUpdateValue(NodeValueImpl('name', t.current.key));

     var pp =  profile.entries.iterator;

     //print('=========');
     while(pp.moveNext()){

        if(pp.current.key != 'UUID'){

          NodeValue nodeValue = NodeValueImpl(pp.current.key.toString(), pp.current.value.toString());
          await temp.addOrUpdateValue(nodeValue);
          //print(pp.current.key + pp.current.value);
          //log(temp.toString());
        }

     }

     try {
      //await profiles.addChild(temp);

      await Storage.controller!.addOrUpdate(temp);
     } catch (e, s) {
      print(e);
     }

  }


  var prget = await Storage.controller!.get(':Global:profiles');
  var datas = await prget.getChildren();
  log(datas.toString());
  //print(datas.toString());

}

Future createRecommendations() async{


  Node recommendations = NodeImpl(':Global:Recommendations','');
  try {
    await Storage.controller!.addOrUpdate(recommendations);
  } catch (e, s) {
    print(s);
  }

  //Map x = json.decode(await File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/recommendations.json').readAsString());


  var t =  data.reco.entries.iterator;

  while(t.moveNext()){

    var recommendation = t.current.value;
    Node temp = NodeImpl(recommendation['UUID'].toString(), '',':Global:Recommendations');
    await temp.addOrUpdateValue(NodeValueImpl('short', recommendation['short'].toString()));
    await temp.addOrUpdateValue(NodeValueImpl('relatedThreatsWeights', recommendation['relatedThreatsWeights'].toString()));
    await temp.addOrUpdateValue(NodeValueImpl('RecommendationType', recommendation['RecommendationType'].toString()));
    await Storage.controller!.addOrUpdate(temp);
    await recommendations.addChild(temp);
  }



  try {
    await Storage.controller!.addOrUpdate(recommendations);
  } catch (e, s) {
    print(s);
  }

//  var get = await Storage.controller!.get(':Global:Recommendations');
//  print(await get.getChildren());
}

Future createEnterprise() async{

  //:Enterprise
//  Node enterprise = NodeImpl(':Enterprise');
//  Storage.controller!.addOrUpdate(enterprise);

//  final input =  File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/Enterprise.csv').openRead();
//  final fields = await input.transform(utf8.decoder).transform(CsvToListConverter()).toList();

//  for ( var str in fields[0].toString().replaceAll('[', '').split('\n') ){

    try {

      Node temp = NodeImpl(data.enter['UUID'].toString(),'', ':Enterprise');
      await temp.addOrUpdateValue(NodeValueImpl('name', data.enter['Name'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('location', data.enter['location'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('sector', data.enter['sector'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('associatedProfiles', data.enter['associatedProfiles'].toString()));

      await Storage.controller!.addOrUpdate(temp);
    }
    catch(e){

      print(e);

    }
 // }

//  var get = await Storage.controller!.get(':Enterprise');
//  print(await get.getChildren());

}


Future createEnterpriseDevices() async{

  //:Enterprise
//  Node enterprise = NodeImpl(':Enterprise');
//  Storage.controller!.addOrUpdate(enterprise);

//  final input =  File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/enterpriseDevices.csv').openRead();
//  final fields = await input.transform(utf8.decoder).transform(CsvToListConverter()).toList();


  for ( var str in data.enterDevice ){

    try {

      Node temp = NodeImpl(str['UUID'].toString(),'', ':Devices');
      await temp.addOrUpdateValue(NodeValueImpl('name', str['name'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('type', str['type'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('owner', str['owner'].toString()));
      await Storage.controller!.addOrUpdate(temp);
    }

    catch(e){

      print(e);
    }
  }

  Node temp = await Storage.controller!.get(':Devices:'+Storage.deviceUUID);
  await temp.addOrUpdateValue(NodeValueImpl('name', 'geiger'));
  await temp.addOrUpdateValue(NodeValueImpl('type', 'mobile'));
  await temp.addOrUpdateValue(NodeValueImpl('owner', Storage.userUUID));
  await Storage.controller!.addOrUpdate(temp);


//  var get = await Storage.controller!.get(':Devices');
//  print(await get.getChildren());

  //print(Storage.controller!.get(':Devices').getChildren());

}


Future createEnterpriseUsers() async {

  //":Global:profiles"
  Node enterpriseUsers = NodeImpl(':Enterprise:users','');
  try {
    await Storage.controller!.addOrUpdate(enterpriseUsers);
  } catch (e, s) {
    print(s);
  }

 // Map x = json.decode(await File(dirname(Platform.script.path)+'/test/dummyAPI/dummydata/enterpriseUsers.json').readAsString());


  var t =  data.enterUsers.entries.iterator;

  while(t.moveNext()){

    var nodeArrays = t.current.value;

    for(var node in nodeArrays){

      Node temp = NodeImpl(node['UUID'].toString(),'', ':Enterprise:users');
      await temp.addOrUpdateValue(NodeValueImpl('name',node['name'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('firstName',node['firstName'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('UUIDs',node['UUIDs'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('mainUser',node['mainUser'].toString()));
      await temp.addOrUpdateValue(NodeValueImpl('supervising',node['supervising'].toString()));

      await enterpriseUsers.addChild(temp);

    }


  }

  Node temp = NodeImpl(Storage.userUUID,'', ':Enterprise:users');
  await temp.addOrUpdateValue(NodeValueImpl('name','geiger'));
  await temp.addOrUpdateValue(NodeValueImpl('firstName','g'));
  await temp.addOrUpdateValue(NodeValueImpl('UUIDs',Storage.userUUID));
  await temp.addOrUpdateValue(NodeValueImpl('mainUser','1'));
  await temp.addOrUpdateValue(NodeValueImpl('supervising','328161f6-89bd-49f6-user-5a375ff56ben, 328161f6-89bd-49f6-user-5a375ff58cal, 328161f6-89bd-49f6-user-5a375ff58deb'));

  await enterpriseUsers.addChild(temp);

  try {
    await Storage.controller!.addOrUpdate(enterpriseUsers);
  } catch (e, s) {
    print(s);
  }
//
//  var get = await Storage.controller!.get(':Devices');
//  print(await get.getChildren());



}



//Future createLocal() async {
//
//  Storage.userUUID = await Storage().getUUID('currentUser');
//  print('proxy'+Storage.userUUID);
//
//  Storage.deviceUUID = await Storage().getUUID('currentDevice');
//
//  print('proxy'+Storage.deviceUUID);
//}



Future createDeviceData(var body) async{


  //create :Users:tool_iD:plugin_UUID:data node paths

  body['name'] = 'Awareness and training scores';
  body['flag'] = '0';


  //var t =  body.entries.iterator;

  //var companyUUID = body.entries.first.value['cUUID'];

  var companyUUID = body['cUUID'];

  await Storage.controller!.addOrUpdate(NodeImpl(companyUUID,'', ':Devices:' + Storage.deviceUUID));
  await Storage.controller!.addOrUpdate(NodeImpl('data','', ':Devices:' + Storage.deviceUUID + ':' + companyUUID));
  await Storage.controller!.addOrUpdate(NodeImpl('metrics','', ':Devices:' + Storage.deviceUUID + ':' + companyUUID+':data'));

//  while(t.moveNext()){
//
//  var node = t.current.value;


  Node temp = NodeImpl(body['mUUID'],'', ':Devices:' + Storage.deviceUUID + ':' + body['cUUID']+':data:metrics');
  await temp.addOrUpdateValue(NodeValueImpl('name', body['name']));
  await temp.addOrUpdateValue(NodeValueImpl('minValue', body['minValue']));
  await temp.addOrUpdateValue(NodeValueImpl('maxValue', body['maxValue']));
  await temp.addOrUpdateValue(NodeValueImpl('GEIGERvalue', body['geigerValue']));
  await temp.addOrUpdateValue(NodeValueImpl('valueType', body['valueType']));
  await temp.addOrUpdateValue(NodeValueImpl('flag', body['flag']));
  await temp.addOrUpdateValue(NodeValueImpl('threatsImpact', body['threatsImpact']));

  await Storage.controller!.addOrUpdate(temp);


  SearchCriteria s = SearchCriteria(searchPath: ':Devices');
  s.set(Field.type,'GEIGERvalue');
  await s.evaluate(temp);
//  }

  // print(await Storage.controller!.get(':Devices:' + Storage.deviceUUID + ':' + companyUUID +':data:metrics'));

}



Future createUserData(var body) async{


  //create :Users:tool_iD:plugin_UUID:data node paths

  body['name'] = 'Awareness and training scores';
  body['flag'] = '1';
//{geigerValue: 32.5, minValue: 0, cUUID: 5a6487c7-c1c5-4f28-995e-8805e45bf1a3, maxValue: 100, valueType: double, mUUID: 123e4567-e89b-42d3-a456-556642440sdk-m01, threatsImpact: 80efffaf-98a1-4e0a-8f5e-gr89388352ph,High;80efffaf-98a1-4e0a-8f5e-gr89388354sp,Hight;80efffaf-98a1-4e0a-8f5e-th89388365it,Hight;80efffaf-98a1-4e0a-8f5e-gr89388350ma,Medium;80efffaf-98a1-4e0a-8f5e-gr89388356db,Medium}

  //var t =  body.entries.iterator;

  var companyUUID = body['cUUID'];

  await Storage.controller!.addOrUpdate(NodeImpl(companyUUID,'', ':Users:' + Storage.userUUID));
  await Storage.controller!.addOrUpdate(NodeImpl('data','', ':Users:' + Storage.userUUID + ':' + companyUUID));
  await Storage.controller!.addOrUpdate(NodeImpl('metrics','', ':Users:' + Storage.userUUID + ':' + companyUUID+':data'));



  //while(t.moveNext()){

  //var node = t.current.value;


  Node temp = NodeImpl(body['mUUID'],'', ':Users:' + Storage.userUUID + ':' + body['cUUID']+':data:metrics');
  //print(temp.path);
  await temp.addOrUpdateValue(NodeValueImpl('name', body['name']));
  await temp.addOrUpdateValue(NodeValueImpl('minValue', body['minValue']));
  await temp.addOrUpdateValue(NodeValueImpl('maxValue', body['maxValue']));
  await temp.addOrUpdateValue(NodeValueImpl('GEIGERvalue', body['geigerValue']));
  await temp.addOrUpdateValue(NodeValueImpl('valueType', body['valueType']));
  await temp.addOrUpdateValue(NodeValueImpl('flag', body['flag']));
  await temp.addOrUpdateValue(NodeValueImpl('threatsImpact', body['threatsImpact']));

  await Storage.controller!.addOrUpdate(temp);

  SearchCriteria s = SearchCriteria(searchPath: ':Users');
  s.set(Field.type,'GEIGERvalue');
  await s.evaluate(temp);


  //}

//  var prget = await Storage.controller!.get(':Users:' + Storage.userUUID + ':' + companyUUID +':data:metrics');
//  var re = await prget.getChildren();
//  log(re.toString());

}
